@@ -508,6 +508,10 @@ jsRepeatedGadjet <- function(data, nfactor.limit = 20) {
                 options = c(jstable::opt.tbreg("roctable"), list(scrollX = TRUE)))
     })
 
+    session$onSessionEnded(function() {
+      stopApp()
+    })
+
   }
 
 
@@ -827,6 +831,10 @@ jsRepeatedExtAddin <- function(nfactor.limit = 20, max.filesize = 2048){
       datatable(out_timeroc()$tb, rownames=F, editable = F, extensions= "Buttons", caption = "ROC results",
                 options = c(jstable::opt.tbreg("roctable"), list(scrollX = TRUE)))
     })
+
+    session$onSessionEnded(function() {
+      stopApp()
+    })
   }
 
   #viewer <- dialogViewer("Descriptive statistics", width = 1100, height = 850)
